@@ -33,7 +33,6 @@ from shapely.ops import unary_union
 from . import settings
 from .projection import project_geometry
 from .projection import project_gdf
-from .settings import default_crs
 from .simplify import simplify_graph
 from .utils import log
 from .utils import make_str
@@ -79,7 +78,7 @@ def save_to_cache(url, response_json):
             # hash the url (to make filename shorter than the often extremely
             # long url)
             filename = hashlib.md5(url.encode('utf-8')).hexdigest()
-            cache_path_filename = '{}/{}.json'.format(settings.cache_folder, filename)
+            cache_path_filename = os.path.join(settings.cache_folder, os.extsep.join([filename, 'json']))
 
             # dump to json, and save to file
             json_str = make_str(json.dumps(response_json))
@@ -106,7 +105,8 @@ def get_from_cache(url):
     if settings.use_cache:
         # determine the filename by hashing the url
         filename = hashlib.md5(url.encode('utf-8')).hexdigest()
-        cache_path_filename = '{}/{}.json'.format(settings.cache_folder, filename)
+
+        cache_path_filename = os.path.join(settings.cache_folder, os.extsep.join([filename, 'json']))
         # open the cache file for this url hash if it already exists, otherwise
         # return None
         if os.path.isfile(cache_path_filename):
@@ -434,7 +434,7 @@ def gdf_from_place(query, gdf_name=None, which_result=1, buffer_dist=None):
         # create the GeoDataFrame, name it, and set its original CRS to default_crs
         gdf = gpd.GeoDataFrame.from_features(features)
         gdf.gdf_name = gdf_name
-        gdf.crs = default_crs
+        gdf.crs = settings.default_crs
 
         # if buffer_dist was passed in, project the geometry to UTM, buffer it
         # in meters, then project it back to lat-long
@@ -485,7 +485,7 @@ def gdf_from_places(queries, gdf_name='unnamed', buffer_dist=None):
     gdf.gdf_name = gdf_name
 
     # set the original CRS of the GeoDataFrame to default_crs, and return it
-    gdf.crs = default_crs
+    gdf.crs = settings.default_crs
     log('Finished creating GeoDataFrame with {} rows from {} queries'.format(len(gdf), len(queries)))
     return gdf
 
@@ -512,32 +512,33 @@ def get_osm_filter(network_type):
     # services
     filters['drive'] = ('["area"!~"yes"]["highway"!~"cycleway|footway|path|pedestrian|steps|track|corridor|'
                         'proposed|construction|bridleway|abandoned|platform|raceway|service"]'
-                        '["motor_vehicle"!~"no"]["motorcar"!~"no"]["access"!~"private|no"]'
-                        '["service"!~"parking|parking_aisle|driveway|private|emergency_access"]')
+                        '["motor_vehicle"!~"no"]["motorcar"!~"no"]{}'
+                        '["service"!~"parking|parking_aisle|driveway|private|emergency_access"]').format(settings.default_access)
 
     # drive+service: allow ways tagged 'service' but filter out certain types of
     # service ways
     filters['drive_service'] = ('["area"!~"yes"]["highway"!~"cycleway|footway|path|pedestrian|steps|track|corridor|'
                                 'proposed|construction|bridleway|abandoned|platform|raceway"]'
-                                '["motor_vehicle"!~"no"]["motorcar"!~"no"]["access"!~"private|no"]'
-                                '["service"!~"parking|parking_aisle|private|emergency_access"]')
+                                '["motor_vehicle"!~"no"]["motorcar"!~"no"]{}'
+                                '["service"!~"parking|parking_aisle|private|emergency_access"]').format(settings.default_access)
 
     # walking: filter out cycle ways, motor ways, private ways, and anything
     # specifying foot=no. allow service roads, permitting things like parking
     # lot lanes, alleys, etc that you *can* walk on even if they're not exactly
-    # pleasant walks
+    # pleasant walks. some cycleways may allow pedestrians, but this filter ignores
+    # such cycleways.
     filters['walk'] = ('["area"!~"yes"]["highway"!~"cycleway|motor|proposed|construction|abandoned|platform|raceway"]'
-                       '["foot"!~"no"]["service"!~"private"]["access"!~"private|no"]')
+                       '["foot"!~"no"]["service"!~"private"]{}').format(settings.default_access)
 
     # biking: filter out foot ways, motor ways, private ways, and anything
     # specifying biking=no
     filters['bike'] = ('["area"!~"yes"]["highway"!~"footway|corridor|motor|proposed|construction|abandoned|platform|raceway"]'
-                       '["bicycle"!~"no"]["service"!~"private"]["access"!~"private|no"]')
+                       '["bicycle"!~"no"]["service"!~"private"]{}').format(settings.default_access)
 
     # to download all ways, just filter out everything not currently in use or
     # that is private-access only
     filters['all'] = ('["area"!~"yes"]["highway"!~"proposed|construction|abandoned|platform|raceway"]'
-                      '["service"!~"private"]["access"!~"private|no"]')
+                      '["service"!~"private"]{}').format(settings.default_access)
 
     # to download all ways, including private-access ones, just filter out
     # everything not currently in use
@@ -635,11 +636,11 @@ def osm_net_download(polygon=None, north=None, south=None, east=None, west=None,
         # loop through each polygon rectangle in the geometry (there will only
         # be one if original bbox didn't exceed max area size)
         for poly in geometry:
-            # represent bbox as south,west,north,east and round lat-longs to 8
-            # decimal places (ie, within 1 mm) so URL strings aren't different
+            # represent bbox as south,west,north,east and round lat-longs to 6
+            # decimal places (ie, ~100 mm) so URL strings aren't different
             # due to float rounding issues (for consistent caching)
             west, south, east, north = poly.bounds
-            query_template = '[out:json][timeout:{timeout}]{maxsize};({infrastructure}{filters}({south:.8f},{west:.8f},{north:.8f},{east:.8f});>;);out;'
+            query_template = '[out:json][timeout:{timeout}]{maxsize};({infrastructure}{filters}({south:.6f},{west:.6f},{north:.6f},{east:.6f});>;);out;'
             query_str = query_template.format(north=north, south=south,
                                               east=east, west=west,
                                               infrastructure=infrastructure,
@@ -715,7 +716,7 @@ def consolidate_subdivide_geometry(geometry, max_query_area_size):
 def get_polygons_coordinates(geometry):
     """
     Extract exterior coordinates from polygon(s) to pass to OSM in a query by
-    polygon.
+    polygon. Ignore the interior ("holes") coordinates.
 
     Parameters
     ----------
@@ -746,9 +747,9 @@ def get_polygons_coordinates(geometry):
         s = ''
         separator = ' '
         for coord in list(coords):
-            # round floating point lats and longs to 14 places, so we can hash
-            # and cache strings consistently
-            s = '{}{}{:.14f}{}{:.14f}'.format(s, separator, coord[1], separator, coord[0])
+            # round floating point lats and longs to 6 decimal places (ie, ~100 mm),
+            # so we can hash and cache strings consistently
+            s = '{}{}{:.6f}{}{:.6f}'.format(s, separator, coord[1], separator, coord[0])
         polygon_coord_strs.append(s.strip(separator))
 
     return polygon_coord_strs
@@ -1133,8 +1134,7 @@ def truncate_graph_polygon(G, polygon, retain_all=False, truncate_by_edge=False,
     G.remove_nodes_from(nodes_outside_polygon['node'])
     log('Removed {:,} nodes outside polygon in {:,.2f} seconds'.format(len(nodes_outside_polygon), time.time()-start_time))
 
-    # remove any isolated nodes and retain only the largest component (if
-    # retain_all is True)
+    # remove any isolated nodes and retain only the largest component (if retain_all is False)
     if not retain_all:
         G = remove_isolated_nodes(G)
         G = get_largest_component(G)
@@ -1171,7 +1171,8 @@ def add_edge_lengths(G):
                                     lat2=df_coords['v_y'],
                                     lng2=df_coords['v_x'])
 
-    gc_distances = gc_distances.fillna(value=0)
+    # fill nulls with zeros and round to the millimeter
+    gc_distances = gc_distances.fillna(value=0).round(3)
     nx.set_edge_attributes(G, name='length', values=gc_distances.to_dict())
 
     log('Added edge lengths to graph in {:,.2f} seconds'.format(time.time()-start_time))
@@ -1296,7 +1297,7 @@ def create_graph(response_jsons, name='unnamed', retain_all=False, network_type=
         raise ValueError('There are no data elements in the response JSON objects')
 
     # create the graph as a MultiDiGraph and set the original CRS to default_crs
-    G = nx.MultiDiGraph(name=name, crs=default_crs)
+    G = nx.MultiDiGraph(name=name, crs=settings.default_crs)
 
     # extract nodes and paths from the downloaded osm data
     nodes = {}
@@ -1654,8 +1655,9 @@ def graph_from_polygon(polygon, network_type='all_private', simplify=True,
         if True (and simplify=True), buffer 0.5km to get a graph larger than
         requested, then simplify, then truncate it to requested spatial extent
     infrastructure : string
-        download infrastructure of given type (default is streets (ie, 'way["highway"]') but other
-        infrastructures may be selected like power grids (ie, 'way["power"~"line"]'))
+        download infrastructure of given type (default is streets
+        (ie, 'way["highway"]') but other infrastructures may be selected 
+        like power grids (ie, 'way["power"~"line"]'))
 
     Returns
     -------
@@ -1667,7 +1669,10 @@ def graph_from_polygon(polygon, network_type='all_private', simplify=True,
     if not polygon.is_valid:
         raise ValueError('Shape does not have a valid geometry')
     if not isinstance(polygon, (Polygon, MultiPolygon)):
-        raise ValueError('Geometry must be a shapely Polygon or MultiPolygon')
+        raise ValueError('Geometry must be a shapely Polygon or MultiPolygon. If you requested '
+                         'graph from place name or address, make sure your query resolves to a '
+                         'Polygon or MultiPolygon, and not some other geometry, like a Point. '
+                         'See OSMnx documentation for details.')
 
     if clean_periphery and simplify:
         # create a new buffered polygon 0.5km around the desired one
