@@ -23,7 +23,6 @@ from .core import graph_from_point
 from .core import bbox_from_point
 from .projection import project_graph
 from .save_load import graph_to_gdfs
-from .settings import default_crs
 from .simplify import simplify_graph
 from .utils import log
 
@@ -247,7 +246,7 @@ def save_and_show(fig, ax, save, show, close, filename, file_format, dpi, axis_o
         # create the save folder if it doesn't already exist
         if not os.path.exists(settings.imgs_folder):
             os.makedirs(settings.imgs_folder)
-        path_filename = '{}/{}.{}'.format(settings.imgs_folder, filename, file_format)
+        path_filename = os.path.join(settings.imgs_folder, os.extsep.join([filename, file_format]))
 
         if file_format == 'svg':
             # if the file_format is svg, prep the fig/ax a bit for saving
@@ -293,7 +292,8 @@ def plot_graph(G, bbox=None, fig_height=6, fig_width=None, margin=0.02,
     G : networkx multidigraph
     bbox : tuple
         bounding box as north,south,east,west - if None will calculate from
-        spatial extents of data
+        spatial extents of data. if passing a bbox, you probably also want to
+        pass margin=0 to constrain it.
     fig_height : int
         matplotlib figure height in inches
     fig_width : int
@@ -403,8 +403,11 @@ def plot_graph(G, bbox=None, fig_height=6, fig_width=None, margin=0.02,
     ax.set_xlim((west - margin_ew, east + margin_ew))
 
     # configure axis appearance
-    ax.get_xaxis().get_major_formatter().set_useOffset(False)
-    ax.get_yaxis().get_major_formatter().set_useOffset(False)
+    xaxis = ax.get_xaxis()
+    yaxis = ax.get_yaxis()
+
+    xaxis.get_major_formatter().set_useOffset(False)
+    yaxis.get_major_formatter().set_useOffset(False)
 
     # if axis_off, turn off the axis display set the margins to zero and point
     # the ticks in so there's no space around the plot
@@ -412,6 +415,8 @@ def plot_graph(G, bbox=None, fig_height=6, fig_width=None, margin=0.02,
         ax.axis('off')
         ax.margins(0)
         ax.tick_params(which='both', direction='in')
+        xaxis.set_visible(False)
+        yaxis.set_visible(False)
         fig.canvas.draw()
 
     if equal_aspect:
@@ -420,7 +425,7 @@ def plot_graph(G, bbox=None, fig_height=6, fig_width=None, margin=0.02,
         fig.canvas.draw()
     else:
         # if the graph is not projected, conform the aspect ratio to not stretch the plot
-        if G.graph['crs'] == default_crs:
+        if G.graph['crs'] == settings.default_crs:
             coslat = np.cos((min(node_Ys) + max(node_Ys)) / 2. / 180. * np.pi)
             ax.set_aspect(1. / coslat)
             fig.canvas.draw()
@@ -456,7 +461,8 @@ def plot_graph_route(G, route, bbox=None, fig_height=6, fig_width=None,
         the route as a list of nodes
     bbox : tuple
         bounding box as north,south,east,west - if None will calculate from
-        spatial extents of data
+        spatial extents of data. if passing a bbox, you probably also want to
+        pass margin=0 to constrain it.
     fig_height : int
         matplotlib figure height in inches
     fig_width : int
